'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api

from .Properties import Properties


class GroupAccount(EzxMsg, metaclass=EzxMsgMeta):

	__block_fields__ = {
		'PRPSBLK' : Field('settings', 'PRPSBLK', noop_decode_func, ), 
	}

	def __init__(self, **kwargs):
		self.id : str = None
		self.displayName : str = None
		self.ownerID : str = None
		self.settings : Properties = None
		self.isDefault : int = None
		self.notes : str = None
		super(GroupAccount, self).__init__(**kwargs)

