'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api



class AllocInfo(EzxMsg, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		self.allocInfoID : int = None
		self.legNum : int = None
		self.allocAccount : str = None
		self.allocAvgPx : float = None
		self.allocShares : float = None
		self.allocText : str = None
		self.processCode : str = None
		self.brokerOfCredit : str = None
		self.commType : str = None
		self.commission : float = None
		super(AllocInfo, self).__init__(**kwargs)

