'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api



class AccountInfo(EzxMsg, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		self.accountID : str = None
		self.accountName : str = None
		self.groupID : str = None
		self.rrID : str = None
		self.branchName : str = None
		super(AccountInfo, self).__init__(**kwargs)

