'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api

from .QuoteRecord import QuoteRecord


class Quote(EzxMsg, metaclass=EzxMsgMeta):

	__block_fields__ = {
		'QUOTE' : Field('quoteRecords', 'QUOTE', noop_decode_func, update_list_item), 
	}

	def __init__(self, **kwargs):
		self.iServerTime : float = None
		self.engMsgRcvTime : float = None
		self.quoteDateTime : str = None
		self.quoteRecords : list[QuoteRecord] = None
		super(Quote, self).__init__(**kwargs)
		self.msg_type = api.IserverMsgType.APPLICATION.value
		self.msg_subtype = api.IserverMsgSubType.QUOTE.value

