'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api

from .GroupAccount import GroupAccount


class ReadGroupAccounts(EzxMsg, metaclass=EzxMsgMeta):

	__block_fields__ = {
		'GRPACC' : Field('groupAccounts', 'GRPACC', noop_decode_func, update_list_item), 
	}

	def __init__(self, **kwargs):
		self.groupAccounts : list[GroupAccount] = None
		super(ReadGroupAccounts, self).__init__(**kwargs)
		self.msg_type = api.IserverMsgType.COMMAND.value
		self.msg_subtype = api.IserverMsgSubType.READ_GROUP_ACCOUNTS.value

