'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api

from .TagValueMsg import TagValueMsg
from .TagValueMsg import TagValueMsg


class Strategy(EzxMsg, metaclass=EzxMsgMeta):

	__block_fields__ = {
		'STRATSETTVS' : Field('strategySettingTVS', 'STRATSETTVS', noop_decode_func, ), 
		'STRATDEFTVS' : Field('strategyDefaultTVS', 'STRATDEFTVS', noop_decode_func, ), 
	}

	def __init__(self, **kwargs):
		self.strategyName : str = None
		self.screenID : str = None
		self.strategySettingTVS : TagValueMsg = None
		self.strategyDefaultTVS : TagValueMsg = None
		super(Strategy, self).__init__(**kwargs)

