'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api



class ParentOrderStatus(EzxMsg, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		self.version : int = None
		self.updatedVersion : int = None
		self.seqNo : int = None
		self.side : int = None
		self.orderQty : float = None
		self.cumQty : float = None
		self.leavesQty : float = None
		self.placedQty : float = None
		self.totExec : float = None
		self.workingQty : float = None
		self.lnWorkingQty : float = None
		self.executedQty : float = None
		self.lnExecutedQty : float = None
		self.locateReqd : str = None
		self.mgrLimitPx : float = None
		self.tdrLimitPx : float = None
		self.benchmark : float = None
		self.estMktImpact : float = None
		self.parentKey : str = None
		self.myID : str = None
		self.state : str = None
		self.event : str = None
		self.orderEntryTime : str = None
		self.traderReceiptTime : str = None
		self.symbol : str = None
		self.trader : str = None
		self.portfolio : str = None
		self.securityType : str = None
		self.ordType : str = None
		self.country : str = None
		self.currency : str = None
		self.exDest : str = None
		self.securityID : str = None
		self.idSource : str = None
		self.timeStamp : str = None
		self.userInfo : str = None
		self.userName : str = None
		self.openClose : str = None
		self.securityExchange : str = None
		super(ParentOrderStatus, self).__init__(**kwargs)

