'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api



class FixedIncomeMarketDataIncrementalRefresh(EzxMsg, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		self.msgRecvTime : str = None
		self.providerID : str = None
		self.noOfMDEntries : int = None
		self.mdentryType : str = None
		self.mdentryPrice : float = None
		self.mdentrySize : float = None
		self.mdEntryDate : str = None
		self.mdEntryTime : str = None
		self.mdEntryID : str = None
		self.mdUpdateAction : str = None
		self.minQty : float = None
		self.mdMinIncrementOffer : float = None
		self.mdMinBalanceRemainingOffer : float = None
		self.mdYieldToWorst : float = None
		self.mdYieldToMaturity : float = None
		self.mdMineFlag : str = None
		self.mdExecutionType : str = None
		self.securityIDSource : str = None
		self.securityID : str = None
		self.symbol : str = None
		self.product : int = None
		self.mdentryOriginator : str = None
		self.tagValueBlock : str = None
		self.marketDepth : int = None
		self.settlDate : str = None
		super(FixedIncomeMarketDataIncrementalRefresh, self).__init__(**kwargs)
		self.msg_type = api.IserverMsgType.APPLICATION.value
		self.msg_subtype = api.IserverMsgSubType.FIXEDINCOMEMARKETDATAINCREMENTAL.value

