'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''

#Date: 02/24/22
from iserver.msgs import *
api_fields = {
	'dailyAmountTotal' : Field('dailyAmountTotal','DAILYAMT', float, )	,
	'forceLogout' : Field('forceLogout','FLOGOUT', int, )	,
	'addInstructions' : Field('addInstructions','ADDINST', str, )	,
	'mdEntryID' : Field('mdEntryID','317', str, )	,
	'executedQty' : Field('executedQty','EXECQTY', float, )	,
	'clientID' : Field('clientID','CLNTID', int, )	,
	'seqNo' : Field('seqNo','SEQ', int, )	,
	'allocAvgPx' : Field('allocAvgPx','ALLOCAVGPX', float, )	,
	'msgRecvTime' : Field('msgRecvTime','RCTM', str, )	,
	'orderEntryTime' : Field('orderEntryTime','OETIME', str, )	,
	'coverPrice' : Field('coverPrice','CVPX', float, )	,
	'fixEngineName' : Field('fixEngineName','FIXC', str, )	,
	'creditUsed' : Field('creditUsed','CRUSED', float, )	,
	'destinationState' : Field('destinationState','DSTAT', int, )	,
	'userID' : Field('userID','USERID', str, )	,
	'quoteEntryID' : Field('quoteEntryID','283', str, )	,
	'contraBroker' : Field('contraBroker','CONTRABRKR', str, )	,
	'firm' : Field('firm','FRM', str, )	,
	'itemName' : Field('itemName','ITEMNM', str, )	,
	'password' : Field('password','PWD', str, )	,
	'rejectReason' : Field('rejectReason','REJREASON', str, )	,
	'fixConnectionID' : Field('fixConnectionID','CNID', str, )	,
	'txCount' : Field('txCount','TXCNT', int, )	,
	'parentKey3' : Field('parentKey3','PK3', str, )	,
	'rrName' : Field('rrName','RRNAME', str, )	,
	'parentKey1' : Field('parentKey1','PK1', str, )	,
	'yieldType' : Field('yieldType','YTYPE', str, )	,
	'parentKey2' : Field('parentKey2','PK2', str, )	,
	'state' : Field('state','STATE', str, )	,
	'quoteDateTime' : Field('quoteDateTime','ENGRCV', str, )	,
	'mdMsgID' : Field('mdMsgID','273', str, )	,
	'choiceGroupName' : Field('choiceGroupName','GRPNM', str, )	,
	'messageText' : Field('messageText','TXT', str, )	,
	'ySymbol' : Field('ySymbol','YSYM', str, )	,
	'reqState' : Field('reqState','REQSTATE', str, )	,
	'maturityDay' : Field('maturityDay','MATDAY', int, )	,
	'destinations' : Field('destinations','DEST', str, update_list_item)	,
	'yMdSymbol' : Field('yMdSymbol','YMDSYM', str, )	,
	'idSource' : Field('idSource','IDSR', str, )	,
	'ownerID' : Field('ownerID','OID', str, )	,
	'version' : Field('version','VER', int, )	,
	'orderDelayMs' : Field('orderDelayMs','DELAYMS', int, )	,
	'iServerTime' : Field('iServerTime','JTICKS', float, )	,
	'isDefault' : Field('isDefault','ISDFLT', int, )	,
	'stopPrice' : Field('stopPrice','STPX', float, )	,
	'parentKey' : Field('parentKey','PK', str, )	,
	'yAvgPrice' : Field('yAvgPrice','YAVGPX', float, )	,
	'mdMinBalanceRemainingOffer' : Field('mdMinBalanceRemainingOffer','319', float, )	,
	'securityExchange' : Field('securityExchange','SECEXCH', str, )	,
	'replaceThrottleTime' : Field('replaceThrottleTime','REPMS', float, )	,
	'adminResult' : Field('adminResult','RESULT', int, )	,
	'afterHours' : Field('afterHours','AFTERHRS', str, )	,
	'partyID' : Field('partyID','PRTYID', str, )	,
	'dailySharesTotal' : Field('dailySharesTotal','DAILYSHARES', float, )	,
	'filledQty' : Field('filledQty','FQTY', int, )	,
	'hungQty' : Field('hungQty','HQTY', int, )	,
	'logonType' : Field('logonType','TYPE', int, )	,
	'startDate' : Field('startDate','STRTDT', str, )	,
	'systemID' : Field('systemID','SYSID', str, )	,
	'engMsgRcvTime' : Field('engMsgRcvTime','TTIME', float, )	,
	'msgType' : Field('msgType','MTYP', int, )	,
	'ssOrderID' : Field('ssOrderID','SSID', int, )	,
	'displayName' : Field('displayName','NAME', str, )	,
	'lastShares' : Field('lastShares','LSHRS', float, )	,
	'quoteRespID' : Field('quoteRespID','QRESPID', str, )	,
	'clientCreditUsed' : Field('clientCreditUsed','CCRUSED', float, )	,
	'returnDesc' : Field('returnDesc','RETD', str, )	,
	'quoteType' : Field('quoteType','QTYPE', int, )	,
	'sendingTime' : Field('sendingTime','SNTM', str, )	,
	'symbolsfx' : Field('symbolsfx','SYMSFX', str, )	,
	'shares' : Field('shares','SHARES', int, )	,
	'execInstr' : Field('execInstr','EINST', str, )	,
	'errDesc' : Field('errDesc','ERRD', str, )	,
	'pairsSessionID' : Field('pairsSessionID','PRSESSID', int, )	,
	'locateReqd' : Field('locateReqd','LREQD', str, )	,
	'reported' : Field('reported','REPRT', int, )	,
	'commission' : Field('commission','COMM', float, )	,
	'currency' : Field('currency','CURR', str, )	,
	'xSymbol' : Field('xSymbol','XSYM', str, )	,
	'coveredOrUncovered' : Field('coveredOrUncovered','COVUNCOV', int, )	,
	'mdentryOriginator' : Field('mdentryOriginator','MDOG', str, )	,
	'settlementType' : Field('settlementType','STLMT', int, )	,
	'initialScan' : Field('initialScan','ISCAN', float, )	,
	'tagValueBlock' : Field('tagValueBlock','TV', str, )	,
	'mdentryRefID' : Field('mdentryRefID','284', str, )	,
	'mdMinIncrementOffer' : Field('mdMinIncrementOffer','318', float, )	,
	'mdEntryTime' : Field('mdEntryTime','316', str, )	,
	'marketDepth' : Field('marketDepth','351', int, )	,
	'mdentryType' : Field('mdentryType','274', str, )	,
	'noOfMDEntries' : Field('noOfMDEntries','314', int, )	,
	'ySlipAllowance' : Field('ySlipAllowance','YSLIP', float, )	,
	'accessFee' : Field('accessFee','ACCESSFEE', float, )	,
	'positionLimit' : Field('positionLimit','POSLMT', int, )	,
	'lnExecutedQty' : Field('lnExecutedQty','LNEXECQTY', float, )	,
	'ioiTransType' : Field('ioiTransType','IOITRANSTYPE', str, )	,
	'commType' : Field('commType','COMMTYPE', str, )	,
	'quoteCondition' : Field('quoteCondition','277', str, )	,
	'workingQty' : Field('workingQty','WRKQTY', float, )	,
	'country' : Field('country','CTRY', str, )	,
	'symbol' : Field('symbol','SYM', str, )	,
	'userNum' : Field('userNum','UIDN', int, )	,
	'notes' : Field('notes','NOTES', str, )	,
	'yFilledQty' : Field('yFilledQty','YFQTY', int, )	,
	'accruedInterestAmt' : Field('accruedInterestAmt','ACCRUINT', float, )	,
	'gmtEndOfDay' : Field('gmtEndOfDay','DTGMT', str, )	,
	'xAvgPrice' : Field('xAvgPrice','XAVGPX', float, )	,
	'partyIDSource' : Field('partyIDSource','PRTYIDSRC', str, )	,
	'returnCode' : Field('returnCode','RETC', int, )	,
	'legNum' : Field('legNum','LEGNUM', int, )	,
	'traderReceiptTime' : Field('traderReceiptTime','TRTIME', str, )	,
	'creditLimit' : Field('creditLimit','CRLMT', float, )	,
	'refID' : Field('refID','REFID', str, )	,
	'moveAllowance' : Field('moveAllowance','MVALL', float, )	,
	'basketID' : Field('basketID','BSKI', str, )	,
	'mdentrySize' : Field('mdentrySize','276', float, )	,
	'rule10bMinutes' : Field('rule10bMinutes','TENB', int, )	,
	'onBehalfOfCompID' : Field('onBehalfOfCompID','OBCID', str, )	,
	'maturityMonthYear' : Field('maturityMonthYear','MATMONYR', str, )	,
	'accountType' : Field('accountType','ACCTYPE', str, )	,
	'groupID' : Field('groupID','GRPID', str, )	,
	'linkedInboundOrderID' : Field('linkedInboundOrderID','INBNDORDERID', int, )	,
	'isVisible' : Field('isVisible','ISVISI', int, )	,
	'users' : Field('users','UNAM', str, )	,
	'refAllocID' : Field('refAllocID','REFALLOCID', str, )	,
	'riskID' : Field('riskID','RISKID', str, )	,
	'mdentryPositionNumber' : Field('mdentryPositionNumber','278', int, )	,
	'numCompetitors' : Field('numCompetitors','NUMCOMP', int, )	,
	'expireTime' : Field('expireTime','EXPT', str, )	,
	'originatingUser' : Field('originatingUser','UNAM', str, )	,
	'quoteSource' : Field('quoteSource','QSCRC', str, )	,
	'importFileName' : Field('importFileName','IMPFN', str, )	,
	'securityType' : Field('securityType','SECTYPE', str, )	,
	'overRideGroupRestriction' : Field('overRideGroupRestriction','OVRIDE', int, )	,
	'allocTransType' : Field('allocTransType','ALLOCTRANTYPE', int, )	,
	'transactTime' : Field('transactTime','TTIME', str, )	,
	'optAttribute' : Field('optAttribute','OPTATTR', str, )	,
	'yPriceWeight' : Field('yPriceWeight','YPXWGT', float, )	,
	'allocID' : Field('allocID','ALLOCID', str, )	,
	'clientCreditLimit' : Field('clientCreditLimit','CCRLMT', float, )	,
	'idSourceX' : Field('idSourceX','IDSX', str, )	,
	'idSourceY' : Field('idSourceY','IDSY', str, )	,
	'tdrLimitPx' : Field('tdrLimitPx','TLMTPX', float, )	,
	'sendDestStrategies' : Field('sendDestStrategies','SNDDESTSTRAT', int, )	,
	'creditUsageUpdateSecs' : Field('creditUsageUpdateSecs','CUSECS', int, )	,
	'hangAllowance' : Field('hangAllowance','HGALL', int, )	,
	'destination' : Field('destination','DEST', str, )	,
	'importJobName' : Field('importJobName','IMPJN', str, )	,
	'execBroker' : Field('execBroker','EXBRKR', str, )	,
	'iServerGenerated' : Field('iServerGenerated','IGEN', int, )	,
	'mdentryPrice' : Field('mdentryPrice','275', float, )	,
	'quoteStatus' : Field('quoteStatus','QTSTS', int, )	,
	'ezxClientOrderVersion' : Field('ezxClientOrderVersion','EZXCLIDVERSION', int, )	,
	'strategyInfoID' : Field('strategyInfoID','STRATINFOID', int, )	,
	'maxAmountPerOrder' : Field('maxAmountPerOrder','MAXAMTPERORD', float, )	,
	'mdYieldToMaturity' : Field('mdYieldToMaturity','321', float, )	,
	'execType' : Field('execType','EXTYP', int, )	,
	'receivedMethod' : Field('receivedMethod','RECVMTHD', str, )	,
	'exDest' : Field('exDest','EXDST', str, )	,
	'strategyName' : Field('strategyName','STGYNM', str, )	,
	'queueSize' : Field('queueSize','QUSZ', int, )	,
	'myClearingAccount' : Field('myClearingAccount','MYCLRACCT', str, )	,
	'orderID' : Field('orderID','ORDERID', int, )	,
	'pegDiff' : Field('pegDiff','PEGD', float, )	,
	'userName' : Field('userName','UNAM', str, )	,
	'gtcEndOfDay' : Field('gtcEndOfDay','DTGMT', int, )	,
	'decimalPlaces' : Field('decimalPlaces','DECPLCS', int, )	,
	'processCode' : Field('processCode','PROCCODE', str, )	,
	'providerID' : Field('providerID','PVID', str, )	,
	'maxSharesPerOrder' : Field('maxSharesPerOrder','MAXSHARESPERORD', float, )	,
	'positionEffect' : Field('positionEffect','POSEFFECT', str, )	,
	'minQty' : Field('minQty','MINQ', float, )	,
	'userInfo' : Field('userInfo','UINFO', str, )	,
	'companyName' : Field('companyName','CONAM', str, )	,
	'quoteSize' : Field('quoteSize','QSIZE', float, )	,
	'xText' : Field('xText','XTXT', str, )	,
	'quoteID' : Field('quoteID','QUOTEID', str, )	,
	'importTimeStamp' : Field('importTimeStamp','IMPTS', str, )	,
	'allocText' : Field('allocText','ALLOCTEXT', str, )	,
	'lastMkt' : Field('lastMkt','LMKT', str, )	,
	'accountID' : Field('accountID','ACCTID', str, )	,
	'tradingSession' : Field('tradingSession','TRDSESS', str, )	,
	'price' : Field('price','PX', float, )	,
	'discretionaryOffset' : Field('discretionaryOffset','DISOFF', float, )	,
	'options' : Field('options','OPT', str, )	,
	'orderQty' : Field('orderQty','OQTY', float, )	,
	'text' : Field('text','TXT', str, )	,
	'unroutedQty' : Field('unroutedQty','UNRTDQTY', float, )	,
	'id' : Field('id','ID', str, )	,
	'mdHitLiftSide' : Field('mdHitLiftSide','324', str, )	,
	'timeInForce' : Field('timeInForce','TIF', int, )	,
	'senderSubID' : Field('senderSubID','SSUBID', str, )	,
	'clearingFirm' : Field('clearingFirm','CLRFRM', str, )	,
	'mgrLimitPx' : Field('mgrLimitPx','MLMTPX', float, )	,
	'mdUpdateAction' : Field('mdUpdateAction','285', str, )	,
	'sendDestinationState' : Field('sendDestinationState','DSTAT', int, )	,
	'allocInfoID' : Field('allocInfoID','ALLOCINFOID', int, )	,
	'lnWorkingQty' : Field('lnWorkingQty','LNWRKQTY', float, )	,
	'clientOrderLinkID' : Field('clientOrderLinkID','CLORDLINK', str, )	,
	'benchmark' : Field('benchmark','BMRKPX', float, )	,
	'symbolType' : Field('symbolType','SYMT', int, )	,
	'msgOrigin' : Field('msgOrigin','MSGORIGIN', int, )	,
	'ezxClientOrderID' : Field('ezxClientOrderID','EZXCLID', int, )	,
	'exeTimeStamp' : Field('exeTimeStamp','ETIME', str, )	,
	'futSettDate' : Field('futSettDate','FUTSETTLEMENTDATE', str, )	,
	'status' : Field('status','STAT', int, )	,
	'mdYieldToWorst' : Field('mdYieldToWorst','320', float, )	,
	'clientName' : Field('clientName','CLNTNAME', str, )	,
	'avgPrice' : Field('avgPrice','APX', float, )	,
	'heartbeatIntervalSecs' : Field('heartbeatIntervalSecs','HBSECS', int, )	,
	'increment' : Field('increment','INCR', float, )	,
	'carryFirmSubAcct' : Field('carryFirmSubAcct','CARRYFIRM', str, )	,
	'hedgeScan' : Field('hedgeScan','HSCAN', float, )	,
	'benchmarkCurvePoint' : Field('benchmarkCurvePoint','BNCHCPT', float, )	,
	'mdMkt' : Field('mdMkt','352', str, )	,
	'quoteRank' : Field('quoteRank','QTRK', str, )	,
	'origClientOrderID' : Field('origClientOrderID','ORIGCLID', str, )	,
	'referencePrice' : Field('referencePrice','REFPX', float, )	,
	'openClose' : Field('openClose','OPCL', str, )	,
	'myYield' : Field('myYield','YIELD', float, )	,
	'securityIdX' : Field('securityIdX','SECIDX', str, )	,
	'expireDate' : Field('expireDate','EXP', str, )	,
	'securityIdY' : Field('securityIdY','SECIDY', str, )	,
	'event' : Field('event','EVT', str, )	,
	'targetSubID' : Field('targetSubID','TSUBID', str, )	,
	'clearingAcct' : Field('clearingAcct','CLRACT', str, )	,
	'side' : Field('side','SIDE', int, )	,
	'product' : Field('product','PRD', int, )	,
	'pendReq' : Field('pendReq','PENDREQ', str, )	,
	'sendSettings' : Field('sendSettings','SNDSETS', int, )	,
	'updownName' : Field('updownName','UPDWNNM', str, )	,
	'priceOffset' : Field('priceOffset','DISOFF', float, )	,
	'yHedgeWeight' : Field('yHedgeWeight','YHGWGT', float, )	,
	'leavesQty' : Field('leavesQty','LVS', float, )	,
	'priceType' : Field('priceType','PXT', int, )	,
	'numAllocs' : Field('numAllocs','NUMALLOCS', int, )	,
	'rrID' : Field('rrID','RRID', str, )	,
	'sendPosition' : Field('sendPosition','SENDPSTN', int, )	,
	'timeStamp' : Field('timeStamp','TS', str, )	,
	'screenOptions' : Field('screenOptions','SCROPT', str, )	,
	'estMktImpact' : Field('estMktImpact','EMKTIMP', float, )	,
	'exeVersion' : Field('exeVersion','VER', int, )	,
	'contraTrader' : Field('contraTrader','CONTRATRDR', str, )	,
	'brokerOrderID' : Field('brokerOrderID','BOID', str, )	,
	'lastPrice' : Field('lastPrice','LPX', float, )	,
	'date' : Field('date','DT', str, )	,
	'mdEntryDate' : Field('mdEntryDate','315', str, )	,
	'ssExeID' : Field('ssExeID','EID', int, )	,
	'benchmarkSecurityID' : Field('benchmarkSecurityID','NBCHSECID', str, )	,
	'totTotExec' : Field('totTotExec','TTOTEX', float, )	,
	'clientOrderID' : Field('clientOrderID','CLID', str, )	,
	'securityID' : Field('securityID','SECI', str, )	,
	'engineSeqno' : Field('engineSeqno','ESEQ', int, )	,
	'cfiCode' : Field('cfiCode','CFI', str, )	,
	'crossingPrice' : Field('crossingPrice','CRXPX', float, )	,
	'infoType' : Field('infoType','INFOTYPE', int, )	,
	'omsVersion' : Field('omsVersion','OMSVER', str, )	,
	'clientNameID' : Field('clientNameID','CLIENTNAMEID', int, )	,
	'reportFills' : Field('reportFills','REPFILLS', int, )	,
	'portfolio' : Field('portfolio','PFOL', str, )	,
	'engMsgRecvTime' : Field('engMsgRecvTime','ENGRCV', float, )	,
	'yText' : Field('yText','YTXT', str, )	,
	'destinationGroup' : Field('destinationGroup','DESTGRP', str, )	,
	'ogcKey' : Field('ogcKey','OGC', str, )	,
	'positionLimitUsed' : Field('positionLimitUsed','POSLMTUSED', int, )	,
	'mdMineFlag' : Field('mdMineFlag','322', str, )	,
	'customerOrFirm' : Field('customerOrFirm','CUSTORFIR', int, )	,
	'xMdSymbol' : Field('xMdSymbol','XMDSYM', str, )	,
	'fixEngineState' : Field('fixEngineState','STAT', str, )	,
	'initialValue' : Field('initialValue','INITVAL', float, )	,
	'group' : Field('group','GRP', str, )	,
	'userConnID' : Field('userConnID','UCONNID', int, )	,
	'ecnAccessFee' : Field('ecnAccessFee','ECNAFEE', float, )	,
	'ioiID' : Field('ioiID','BOID', str, )	,
	'strikePx' : Field('strikePx','STRIKEPX', float, )	,
	'originalSide' : Field('originalSide','ORIGSIDE', int, )	,
	'mdBwCoverBid' : Field('mdBwCoverBid','325', float, )	,
	'allocAccount' : Field('allocAccount','ALLOCACCT', str, )	,
	'tradeLiquidityIndicator' : Field('tradeLiquidityIndicator','TRLIQIND', str, )	,
	'icebergQty' : Field('icebergQty','MINQ', int, )	,
	'execTransType' : Field('execTransType','EXTRANS', int, )	,
	'putOrCall' : Field('putOrCall','PUTCALL', int, )	,
	'mdExecutionType' : Field('mdExecutionType','323', str, )	,
	'allocRejCode' : Field('allocRejCode','ALLOCREJCD', int, )	,
	'position' : Field('position','PSTN', int, )	,
	'updatedVersion' : Field('updatedVersion','UVER', int, )	,
	'mdReqID' : Field('mdReqID','282', str, )	,
	'ordType' : Field('ordType','OTYP', str, )	,
	'allocShares' : Field('allocShares','ALLOCSHARES', float, )	,
	'destName' : Field('destName','DESTNM', str, )	,
	'settlDate' : Field('settlDate','353', str, )	,
	'maxDistanceFromMarket' : Field('maxDistanceFromMarket','MAXDIST', float, )	,
	'ratioQty' : Field('ratioQty','RATIOQTY', int, )	,
	'accountName' : Field('accountName','ACCTNAME', str, )	,
	'dateGMT' : Field('dateGMT','DTGMT', str, )	,
	'omsOrdType' : Field('omsOrdType','OMSOTYP', str, )	,
	'itemValue' : Field('itemValue','ITEMVAL', str, )	,
	'totExec' : Field('totExec','TOTEX', float, )	,
	'settleDate' : Field('settleDate','QSTLDATE', str, )	,
	'securityIDSource' : Field('securityIDSource','SSRC', str, )	,
	'mpID' : Field('mpID','MPID', str, )	,
	'ezxMdId' : Field('ezxMdId','EZID', str, )	,
	'pairState' : Field('pairState','PRSTATE', str, )	,
	'xSlipAllowance' : Field('xSlipAllowance','XSLIP', float, )	,
	'routerOrderID' : Field('routerOrderID','ROID', int, )	,
	'conditionExpiry' : Field('conditionExpiry','CONDEXP', str, )	,
	'slipAllowance' : Field('slipAllowance','SLIP', float, )	,
	'totCumQty' : Field('totCumQty','TCUMQ', float, )	,
	'fairValue' : Field('fairValue','FV', float, )	,
	'routerAllocID' : Field('routerAllocID','RAID', int, )	,
	'placedQty' : Field('placedQty','PLCD', float, )	,
	'venueType' : Field('venueType','VENUETYP', str, )	,
	'solicited' : Field('solicited','SOLICIT', int, )	,
	'maxFloor' : Field('maxFloor','MAXF', float, )	,
	'allocStatus' : Field('allocStatus','ALLOCSTAT', str, )	,
	'cumQty' : Field('cumQty','CUMQ', float, )	,
	'dispRange' : Field('dispRange','DISPR', float, )	,
	'trader' : Field('trader','TRDR', str, )	,
	'branchName' : Field('branchName','BRANCHNAME', str, )	,
	'tradeDate' : Field('tradeDate','ALLOCTRDDT', str, )	,
	'destinationID' : Field('destinationID','DESTID', int, )	,
	'riskUserType' : Field('riskUserType','RUTYPE', int, )	,
	'command' : Field('command','CMD', str, )	,
	'afterHoursQty' : Field('afterHoursQty','AFTERHRSQTY', float, )	,
	'spread' : Field('spread','SPRD', float, )	,
	'screenID' : Field('screenID','SCRID', str, )	,
	'myID' : Field('myID','MYID', str, )	,
	'avgPx' : Field('avgPx','AVGPX', float, )	,
	'xFilledQty' : Field('xFilledQty','XFQTY', int, )	,
	'handlInstr' : Field('handlInstr','HDLI', int, )	,
	'partyRole' : Field('partyRole','PRTYROL', str, )	,
	'initialPosition' : Field('initialPosition','INITPSTN', int, )	,
	'brokerOfCredit' : Field('brokerOfCredit','BRKOFCRDT', str, )	,
	'clientOrderType' : Field('clientOrderType','CORDERTYP', int, )	,
	'account' : Field('account','ACCT', str, )	,
	'updateType' : Field('updateType','QCHG', int, )	,
}
