'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api
from iserver.msgs.AllocationRequestInfo import AllocationRequestInfo



class AllocationRequest(AllocationRequestInfo, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		super(AllocationRequest, self).__init__(**kwargs)
		self.msg_type = api.IserverMsgType.APPLICATION.value
		self.msg_subtype = api.IserverMsgSubType.ALLOCATION_REQUEST.value

