'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api
from iserver.msgs.GroupAccountChange import GroupAccountChange



class DeleteAccount(GroupAccountChange, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		super(DeleteAccount, self).__init__(**kwargs)
		self.msg_type = api.IserverMsgType.COMMAND.value
		self.msg_subtype = api.IserverMsgSubType.DELETE_ACCOUNT.value

