'''
Created on Oct 21, 2021

@author: Sgoldberg
'''
import unittest
import iserver


class Test(unittest.TestCase):


    def setUp(self):
        pass


    def tearDown(self):
        pass







if __name__ == "__main__":
    #import sys;sys.argv = ['', 'Test.testName']
    unittest.main()