'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api

from .GroupAccount import GroupAccount


class GroupAccountChange(EzxMsg, metaclass=EzxMsgMeta):

	__block_fields__ = {
		'GRPACC' : Field('groupAccount', 'GRPACC', noop_decode_func, ), 
	}

	def __init__(self, **kwargs):
		self.myID : str = None
		self.returnCode : int = None
		self.returnDesc : str = None
		self.groupAccount : GroupAccount = None
		super(GroupAccountChange, self).__init__(**kwargs)

