'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api



class ChangePasswordResponse(EzxMsg, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		self.returnCode : int = None
		self.returnDesc : str = None
		super(ChangePasswordResponse, self).__init__(**kwargs)
		self.msg_type = api.IserverMsgType.APPLICATION.value
		self.msg_subtype = api.IserverMsgSubType.CHANGEPASSWORD_RESPONSE.value

