'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api



class RiskProfile(EzxMsg, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		self.riskID : str = None
		self.maxAmountPerOrder : float = None
		self.maxSharesPerOrder : float = None
		self.dailyAmountTotal : float = None
		self.dailySharesTotal : float = None
		self.afterHoursQty : float = None
		self.afterHours : str = None
		super(RiskProfile, self).__init__(**kwargs)

