'''
 Generated by EZX Code Generator  
Date: 02/24/22 
'''


from iserver.EzxMsg import EzxMsg, EzxMsgMeta
from iserver.msgs import *
from iserver.enums import api



class ClientOrderRequestInfo(EzxMsg, metaclass=EzxMsgMeta):


	def __init__(self, **kwargs):
		self.notes : str = None
		self.addInstructions : str = None
		self.clientNameID : int = None
		self.traderReceiptTime : str = None
		self.orderEntryTime : str = None
		self.msgType : int = None
		self.orderID : int = None
		self.side : int = None
		self.orderQty : float = None
		self.price : float = None
		self.symbol : str = None
		self.symbolsfx : str = None
		self.receivedMethod : str = None
		self.handlInstr : int = None
		self.version : int = None
		self.settlementType : int = None
		self.timeInForce : int = None
		self.stopPrice : float = None
		self.ordType : str = None
		self.idSource : str = None
		self.account : str = None
		self.clientOrderID : str = None
		self.coveredOrUncovered : int = None
		self.customerOrFirm : int = None
		self.currency : str = None
		self.destination : str = None
		self.destinationGroup : str = None
		self.exDest : str = None
		self.execBroker : str = None
		self.execInstr : str = None
		self.expireDate : str = None
		self.expireTime : str = None
		self.locateReqd : str = None
		self.optAttribute : str = None
		self.parentKey1 : str = None
		self.securityID : str = None
		self.securityType : str = None
		self.symbolType : int = None
		self.tagValueBlock : str = None
		self.text : str = None
		self.userInfo : str = None
		self.senderSubID : str = None
		self.targetSubID : str = None
		self.trader : str = None
		self.accountType : str = None
		self.importFileName : str = None
		self.importTimeStamp : str = None
		self.importJobName : str = None
		self.pegDiff : float = None
		self.discretionaryOffset : float = None
		self.minQty : float = None
		self.maxFloor : float = None
		self.dispRange : float = None
		self.timeStamp : str = None
		self.maturityMonthYear : str = None
		self.maturityDay : int = None
		self.clearingAcct : str = None
		self.carryFirmSubAcct : str = None
		self.conditionExpiry : str = None
		self.putOrCall : int = None
		self.strikePx : float = None
		self.mpID : str = None
		self.clientOrderLinkID : str = None
		self.securityExchange : str = None
		self.openClose : str = None
		self.tradingSession : str = None
		self.routerOrderID : int = None
		self.clientOrderType : int = None
		self.solicited : int = None
		self.startDate : str = None
		self.reportFills : int = None
		self.linkedInboundOrderID : int = None
		self.futSettDate : str = None
		self.basketID : str = None
		self.rule10bMinutes : int = None
		self.myID : str = None
		self.referencePrice : float = None
		self.crossingPrice : float = None
		super(ClientOrderRequestInfo, self).__init__(**kwargs)

